@@ -30,6 +30,10 @@ class Prefs(object):
         continue
     return contact_set
 
+  @property
+  def nameservers(self):
+    return self.raw_prefs['nameservers']
+
   @property
   def register(self):
     register = self.raw_prefs['register']
